==> haskell-missingh-1.6.0.1-21-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MissingH
version:              1.6.0.1
visibility:           public
id:                   MissingH-1.6.0.1-ANBYcBEscAD1PDyDLu2Ez1
key:                  MissingH-1.6.0.1-ANBYcBEscAD1PDyDLu2Ez1
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2018 John Goerzen
maintainer:           Andreas Abel
author:               John Goerzen
synopsis:             Large utility library
description:
    @MissingH@ is a library of all sorts of utility functions for Haskell
    programmers.  It is written in pure Haskell and thus should be
    extremely portable and easy to use.

category:             Unclassified
abi:                  4f44cf31107a33fb569a5477e331fec4
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/MissingH-1.6.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/MissingH-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-missingh
hs-libraries:         HSMissingH-1.6.0.1-ANBYcBEscAD1PDyDLu2Ez1
depends:
    array-0.5.4.0 base-4.16.4.0 containers-0.6.5.1 directory-1.3.6.2
    filepath-1.4.2.2 hslogger-1.3.1.0-Coxrxmg5TtVBuknCjgh5r8 mtl-2.2.2
    network-3.1.4.0-2VaTeXEywlqHC2pV2iXMik
    network-bsd-2.8.1.0-8odhSoml6qLDJTfWl3Ma9Z
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    old-time-1.1.0.4-Dlc8YwGlkPi2Y3VNXkrOFg parsec-3.1.15.0
    process-1.6.16.0 regex-compat-0.95.2.1-6r4iKSNuQHkEjgz1ilm8wy
    time-1.11.1.1 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html:         /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-missingh-1.6.0.1-24-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MissingH
version:              1.6.0.1
visibility:           public
id:                   MissingH-1.6.0.1-JFwuvmnCGPgICA7pqFbybB
key:                  MissingH-1.6.0.1-JFwuvmnCGPgICA7pqFbybB
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2018 John Goerzen
maintainer:           Andreas Abel
author:               John Goerzen
synopsis:             Large utility library
description:
    @MissingH@ is a library of all sorts of utility functions for Haskell
    programmers.  It is written in pure Haskell and thus should be
    extremely portable and easy to use.

category:             Unclassified
abi:                  a6455edc769b51f9c54a77888fcd022d
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/MissingH-1.6.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/MissingH-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-missingh
hs-libraries:         HSMissingH-1.6.0.1-JFwuvmnCGPgICA7pqFbybB
depends:
    array-0.5.4.0 base-4.16.4.0 containers-0.6.5.1 directory-1.3.6.2
    filepath-1.4.2.2 hslogger-1.3.1.1-6ZXyyIUfBbTJX9w1e5IHfN mtl-2.2.2
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    network-bsd-2.8.1.0-1Y5x0mszWxhBcPjCNBOVSm
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    old-time-1.1.0.4-Dlc8YwGlkPi2Y3VNXkrOFg parsec-3.1.15.0
    process-1.6.16.0 regex-compat-0.95.2.1-6r4iKSNuQHkEjgz1ilm8wy
    time-1.11.1.1 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html:         /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
